yt.data\_objects.selection\_objects.disk module
===============================================

.. automodule:: yt.data_objects.selection_objects.disk
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
